@@ -1,9 +1,11 @@
-use std::fmt::Formatter;
+use std::fmt::{Display, Formatter};
 use lmaths::*;
 use crate::Shape;
 use crate::util::*;
 
 /// Represent a Rectangle shape
+#[allow(dead_code)]
+#[derive(Clone, Copy, Default, PartialEq, Debug)]
 pub struct AABB {
     /// Top Left Corner
     pub position:Vector2,
@@ -44,8 +46,10 @@ impl Shape for AABB {
     fn support_point(&self, direction: Vector2) -> Vector2 {
         get_max_point(self.corners.iter(), direction, self.position())
     }
+}
 
-    fn display_fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+impl Display for AABB {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "AABB pos({0}), size({1})", self.position, self.size)
     }
 }
\ No newline at end of file
