@@ -1,8 +1,9 @@
-use std::fmt::Formatter;
+use std::fmt::{Display, Formatter};
 use lmaths::*;
 use crate::Shape;
 
 #[allow(dead_code)]
+#[derive(Clone, Copy, Default, PartialEq, Debug)]
 /// A circle represented by a position and a radius
 pub struct Circle {
     pub position:Vector2,
@@ -25,8 +26,10 @@ impl Shape for Circle {
     fn support_point(&self, direction: Vector2) -> Vector2 {
         (direction.normalized() * self.radius) + self.position()
     }
+}
 
-    fn display_fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+impl Display for Circle {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "Circle pos ({0}), radius: {1}", self.position, self.radius)
     }
 }
\ No newline at end of file
