@@ -1,9 +1,10 @@
-use std::fmt::Formatter;
+use std::fmt::{Display, Formatter};
 use lmaths::*;
 use crate::Shape;
 use crate::util::*;
 
 #[allow(dead_code)]
+#[derive(Clone, Default, PartialEq, Debug)]
 /// A Convex polygon, made by at least three vertices.
 pub struct Polygon {
     pub position: Vector2,
@@ -26,8 +27,10 @@ impl Shape for Polygon {
     fn support_point(&self, direction: Vector2) -> Vector2 {
         get_max_point(self.vertices.iter(), direction, self.position())
     }
+}
 
-    fn display_fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+impl Display for Polygon {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
         write!(f, "Polygon pos({0}), vertices_count: {1}", self.position, self.vertices.len())
     }
-}
+}
\ No newline at end of file
